get_data_ready: Format data

Description Usage Arguments

View source: R/get_data_ready.R

Description

This is the function that has been used to format the raw data df_all.

Usage

1
get_data_ready(center = TRUE, scale = TRUE, pca = FALSE)

Arguments

center

a logical. Should data be centered?

scale

a logical. Should data be scaled?

pca

a logical. Should column be transformed and order via a PCA. Note that in this case, data are scaled.


McCannLab/spatial_fingerprints documentation built on March 13, 2021, 12:02 a.m.