scr_fig5: Figures 5, 6 and 7

Description Usage Arguments

View source: R/scr_fig5.R

Description

Code to reproduce figures 5, 6 and 7 as well as Figure S8-S10.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
scr_fig5(
  file = "output/res_lda_nb/all123/res_lda_123.rds",
  meth = c("lda", "nbc", "mlp"),
  ind = 5:7,
  vc_pos1 = NULL,
  vc_pos2 = NULL,
  xl1 = c(0.3, 0.72),
  yl1 = c(0.3, 0.85),
  adj5b = c(-0.03, 0)
)

Arguments

file

path to results for individual performances as well as performances of all pairs and triplets.

meth

a character string that describes the methods, used in the name of files that include the tables exported.

ind

indices of the figures generated.

vc_pos1, vc_pos2

positions of number (labels) on the first figure generated (left and right panel respectively). If NULL then the values selected for the figure in the main text are used.

yl1, xl1

xlim and ylim use in various figures.

adj5b

Vector to adjust the xlim on Fig.5 panel b.


McCannLab/spatial_fingerprints documentation built on March 13, 2021, 12:02 a.m.