View source: R/get_data_ready.R
This is the function that has been used to format the raw data df_all.
1 | get_data_ready(center = TRUE, scale = TRUE, pca = FALSE)
|
center |
a logical. Should data be centered? |
scale |
a logical. Should data be scaled? |
pca |
a logical. Should column be transformed and order via a PCA. Note that in this case, data are scaled. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.