Code to reproduce figures 5, 6 and 7 as well as Figure S8-S10.
1 2 3 4 5 6 7 8 9 10 |
file |
path to results for individual performances as well as performances of all pairs and triplets. |
meth |
a character string that describes the methods, used in the name of files that include the tables exported. |
ind |
indices of the figures generated. |
vc_pos1, vc_pos2 |
positions of number (labels) on the first figure
generated (left and right panel respectively). If |
yl1, xl1 |
xlim and ylim use in various figures. |
adj5b |
Vector to adjust the xlim on Fig.5 panel b. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.